@@ -12,7 +12,7 @@ local $Params::Check::VERBOSE = 1;
 BEGIN {
     use vars        qw[$VERSION @ISA $STACK $CONFIG];
 
-    $VERSION = "-1";
+    $VERSION    =   0.04;
 
     $STACK      =   [];
 }
@@ -22,7 +22,7 @@ BEGIN {
 
 =head1 NAME
 
-Log::Message -- A generic message storing mechanism;
+Log::Message - A generic message storing mechanism;
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ More on this below.
 
 These are individual message items, which are objects that contain
 the user message as well as the meta-data described above.
-See the L<Log::Message::Item> manpage to see how to extract this 
+See the L<Log::Message::Item> manpage to see how to extract this
 meta-data and how to work with the Item objects.
 You should never need to create your own Item objects, but knowing
 about their methods and accessors is important if you want to write
@@ -179,8 +179,8 @@ provided.
 =item verbose
 
 Log::Message makes use of another module to validate its arguments,
-which is called L<Params::Check>, which is a lightweight, yet 
-powerful input checker and parser. (See the L<Params::Check> 
+which is called L<Params::Check>, which is a lightweight, yet
+powerful input checker and parser. (See the L<Params::Check>
 manpage for details).
 
 The verbose setting will control whether this module will
@@ -314,7 +314,7 @@ sub _new_stack {
     };
 
     my $args = check( $tmpl, \%hash, $CONFIG->verbose ) or (
-        warn(loc(q[Could not create a new stack object: %1], 
+        warn(loc(q[Could not create a new stack object: %1],
                 Params::Check->last_error)
         ),
         return
@@ -399,9 +399,9 @@ sub store {
         %hash = @_;
     }
 
-    my $args = check( $tmpl, \%hash ) or ( 
-        warn( loc(q[Could not store error: %1], Params::Check->last_error) ), 
-        return 
+    my $args = check( $tmpl, \%hash ) or (
+        warn( loc(q[Could not store error: %1], Params::Check->last_error) ),
+        return
     );
 
     my $extra = delete $args->{extra};
@@ -488,10 +488,10 @@ sub retrieve {
     }
 
     my $args = check( $tmpl, \%hash ) or (
-        warn( loc(q[Could not parse input: %1], Params::Check->last_error) ), 
-        return 
+        warn( loc(q[Could not parse input: %1], Params::Check->last_error) ),
+        return
     );
-    
+
     my @list =
             grep { $_->tag      =~ /$args->{tag}/       ? 1 : 0 }
             grep { $_->level    =~ /$args->{level}/     ? 1 : 0 }
@@ -561,7 +561,7 @@ This removes all items from the stack and returns them to the caller
 
 sub flush {
     my $self = shift;
-    
+
     return splice @{$self->{STACK}};
 }
 
